# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/41_cell.ipynb.

# %% auto 0
__all__ = ['ALL', 'ESC', 'ENDO', 'GLIA', 'MESO', 'HEMA', 'NEURAL', 'PREGERM', 'CARDIAC', 'SOMITES', 'NEURAL_PROG', 'NEURAL_CREST',
           'TROPHOBLAST', 'RADIAL_GLIA']

# %% ../nbs/41_cell.ipynb 5
ALL = 'all'

ESC = 'esc'

ENDO = 'endo'
GLIA = 'glia'

MESO = 'meso'
HEMA = 'hema'

NEURAL = 'neural'

PREGERM = 'pregerm'
CARDIAC = 'cardiac'
SOMITES = 'somites'

NEURAL_PROG = f'{NEURAL}_prog'
NEURAL_CREST = f'{NEURAL}_crest'

TROPHOBLAST = 'trophblast'
RADIAL_GLIA = f'radial_{GLIA}'
