# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/52_tree.ipynb.

# %% auto 0
__all__ = ['BASE', 'LEAF', 'TREE', 'ROOT', 'NODE']

# %% ../nbs/52_tree.ipynb 6
BASE = 'base'
LEAF = 'leaf'
TREE = 'tree'
ROOT = 'root'
NODE = 'node'
