# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/102_text.ipynb.

# %% auto 0
__all__ = ['WIDTH', 'BREAK_LONG_WORDS']

# %% ../nbs/102_text.ipynb 4
WIDTH = 'width'
BREAK_LONG_WORDS = 'break_long_words'
