# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/20_plot.ipynb.

# %% auto 0
__all__ = ['PLOT', 'PROJ', 'IS2D', 'LABEL', 'TITLE', 'SUPTITLE', 'CMAP', 'COLOR', 'COLOR_MAP', 'EDGECOLOR', 'FACECOLOR',
           'LINECOLOR', 'TAB', 'TABCLN', 'XKCD', 'XKCDCLN', 'PROJECTION', 'LIGHT', 'DARK', 'DEEP', 'MUTED', 'PASTEL',
           'BRIGHT', 'COLORBLIND', 'HLS', 'HUSL', 'MAKO', 'CREST', 'FLARE', 'MAGMA', 'ROCKT', 'VIRIDIS']

# %% ../nbs/20_plot.ipynb 4
from nchr import CLN
from .args import IS

# %% ../nbs/20_plot.ipynb 7
PLOT = 'plot'

PROJ = 'proj'

IS2D = f'{IS}2d'
IS2D = f'{IS}3d'

# %% ../nbs/20_plot.ipynb 9
LABEL = 'label'

TITLE = 'title'
SUPTITLE = f'sup{TITLE}'

# %% ../nbs/20_plot.ipynb 11
CMAP = 'cmap'

COLOR = 'color'
COLOR_MAP = f'{COLOR}_map'

EDGECOLOR = f'edge{COLOR}'
FACECOLOR = f'face{COLOR}'
LINECOLOR = f'line{COLOR}'

# %% ../nbs/20_plot.ipynb 13
TAB = 'tab'
TABCLN = f'{TAB}{CLN}'

XKCD = 'xkcd'
XKCDCLN = f'{XKCD}{CLN}'

# %% ../nbs/20_plot.ipynb 15
PROJECTION = f'{PROJ}ection'

# %% ../nbs/20_plot.ipynb 18
LIGHT = 'light'
DARK = 'dark'
_R = '_r'

# %% ../nbs/20_plot.ipynb 20
DEEP = 'deep'
MUTED = 'muted'
PASTEL = 'pastel'
BRIGHT = 'bright'
DARK = 'dark'
COLORBLIND = 'colorblind'

# %% ../nbs/20_plot.ipynb 22
HLS = 'hls'
HUSL = 'husl'

# %% ../nbs/20_plot.ipynb 24
MAKO = 'mako'
CREST = 'crest'
FLARE = 'flare'
MAGMA = 'magma'
ROCKT = 'rocket'
VIRIDIS = 'viridis'
