# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/31_mthd.ipynb.

# %% auto 0
__all__ = ['DPT', 'PCA', 'AUTO', 'UMAP', 'TSNE', 'PHATE', 'MAGIC', 'SCORE', 'ZSCORE', 'GZSCORE', 'L1', 'L2', 'LOG', 'LOG1P', 'OT',
           'MMD', 'PSEUDO', 'PSEUDOTIME', 'DPT_PSEUDOTIME', 'PCS', 'COMP', 'LOAD', 'PROJ', 'COMPONENTS', 'LOADINGS',
           'PROJECTION', 'PROJECTIONS', 'SVD', 'LANDMARK', 'N_SVD', 'N_LANDMARK', 'SEED', 'RANDOM_STATE', 'GRAPH', 'G',
           'P', 'A', 'K', 'KMEANS', 'JOBS', 'NJOBS', 'N_JOBS', 'CENT', 'CENTS', 'CENTROIDS', 'EUCLIDEAN', 'MAP', 'DIFF',
           'DIFFUSION', 'AFFINITY', 'DISTANCE', 'DIFFUSION_MAP', 'DIFFUSION_AFFINITY']

# %% ../nbs/31_mthd.ipynb 4
from nchr import U1
from .exps import TIME

# %% ../nbs/31_mthd.ipynb 6
DPT   = 'dpt'
PCA   = 'pca'

AUTO = 'auto'

UMAP  = 'umap'
TSNE  = 'tsne'
PHATE = 'phate'
MAGIC = 'magic'

SCORE = 'score'
ZSCORE = f'z{SCORE}'
GZSCORE = f'g{ZSCORE}'


L1 = 'l1'
L2 = 'l2'
LOG = 'log'
LOG1P = f'{LOG}1p'

OT = 'ot'
MMD = 'mmd'

# %% ../nbs/31_mthd.ipynb 7
PSEUDO = 'pseudo'
PSEUDOTIME = f'{PSEUDO}{TIME}'
DPT_PSEUDOTIME = f'{DPT}{U1}{PSEUDOTIME}'

# %% ../nbs/31_mthd.ipynb 8
PCS = 'pcs'

COMP = 'comp'
LOAD = 'load'
PROJ = 'proj'

COMPONENTS = f'{COMP}onents'
LOADINGS = f'{LOAD}ings'

PROJECTION = f'{PROJ}ection'
PROJECTIONS = f'{PROJECTION}s'

# %% ../nbs/31_mthd.ipynb 9
SVD = 'svd'
LANDMARK = 'landmark'

N_SVD = f'n_{SVD}'
N_LANDMARK = f'n_{LANDMARK}'

# %% ../nbs/31_mthd.ipynb 10
SEED = 'seed'
RANDOM_STATE = 'random_state'

# %% ../nbs/31_mthd.ipynb 11
GRAPH = 'graph'
G = 'g'
P = 'p'
A = 'a'
K = 'k'

KMEANS = f'{K}means'

# %% ../nbs/31_mthd.ipynb 12
JOBS = 'jobs'
NJOBS = f'n{JOBS}'
N_JOBS = f'n_{JOBS}'

# %% ../nbs/31_mthd.ipynb 13
CENT = 'cent'
CENTS = f'{CENT}s'
CENTROIDS = f'{CENT}roids'

# %% ../nbs/31_mthd.ipynb 14
EUCLIDEAN = 'euclidean'

# %% ../nbs/31_mthd.ipynb 15
MAP = 'map'
DIFF = 'diff'
DIFFUSION = f'{DIFF}usion'
AFFINITY = 'affinity'
DISTANCE = 'distance'
DIFFUSION_MAP = f'{DIFFUSION}{U1}{MAP}'
DIFFUSION_AFFINITY = f'{DIFFUSION}{U1}{AFFINITY}'
