# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_args.ipynb.

# %% auto 0
__all__ = ['N', 'IS', 'DF', 'DS', 'DX', 'ALT', 'HAS', 'GET', 'GOT', 'SET', 'GEN', 'CON', 'DEC', 'IDX', 'SEP', 'FMT', 'KEY', 'POS',
           'CAT', 'ERR', 'RET', 'MSG', 'ATTR', 'DESC', 'FUNC', 'KIND', 'TYPE', 'REPR', 'OPTS', 'SHOW', 'PREF', 'KEYS',
           'PREP', 'PROP', 'DECO', 'LINK', 'PATH', 'PROPS', 'ATTRS', 'TYPES', 'FUNCS', 'HUSH', 'SELF', 'QUIET', 'RAISE',
           'FAILQ', 'SPEC', 'SPECS', 'ANTI', 'PTTN', 'PATTERN', 'ANTI_PTTN', 'DEBUG', 'PRINT', 'VALUE', 'GUARD',
           'ERROR', 'COLOR', 'LABEL', 'TITLE', 'NBINS', 'CUTOFF', 'MIXINS', 'UNIQUE', 'HIDDEN', 'IGNORE', 'ORIGIN',
           'DEFAULT', 'INPLACE', 'VERBOSE', 'REVERSE', 'EXCLUDE', 'SPECIAL', 'OPTIONAL', 'REQUIRED', 'ASMEMBER', 'ABRV',
           'SYMB', 'CONS', 'FMTFUNC', 'MOD', 'PKG', 'ARG', 'KWS', 'VAR', 'KWDS', 'ARGS', 'KWARGS', 'VARS', 'VARG',
           'VKWS', 'VARGS', 'VKWDS', 'VKWARGS', 'DROP', 'DROPNONE', 'BEG', 'END', 'NEG', 'LEN', 'DIG', 'BRV', 'FIX',
           'PREFIX', 'SUFFIX', 'STRS', 'SUNDER', 'DUNDER', 'MANGLED', 'PRIVATE', 'CHAR', 'PROPERTY', 'OVERWRITE',
           'OVERWRITABLE', 'ALTS', 'ALTER', 'ALTERNATES']

# %% ../nbs/02_args.ipynb 5
N = 'n'

# %% ../nbs/02_args.ipynb 6
IS = 'is'

# %% ../nbs/02_args.ipynb 7
DF = 'df'
DS = 'ds'
DX = 'dx'

# %% ../nbs/02_args.ipynb 8
ALT = 'alt'
HAS = 'has'
GET = 'get'
GOT = 'got'
SET = 'set'

# %% ../nbs/02_args.ipynb 9
GEN = 'gen'
CON = 'con'
DEC = 'dec'

# %% ../nbs/02_args.ipynb 10
IDX = 'idx'
SEP = 'sep'
FMT = 'fmt'
KEY = 'key'
POS = 'pos'
CAT = 'cat'

# %% ../nbs/02_args.ipynb 11
ERR = 'err'
RET = 'ret'
MSG = 'msg'

# %% ../nbs/02_args.ipynb 12
ATTR = 'attr'
DESC = 'desc'
FUNC = 'func'
KIND = 'kind'
TYPE = 'type'
REPR = 'repr'
OPTS = 'opts'
SHOW = 'show'
PREF = 'pref'
KEYS = 'keys'
PREP = 'prep'
PROP = 'prop'
DECO = 'deco'


# %% ../nbs/02_args.ipynb 13
LINK = 'link'
PATH = 'path'

# %% ../nbs/02_args.ipynb 14
PROPS = f'{PROP}s'
ATTRS = f'{ATTR}s'
TYPES = f'{TYPE}s'
FUNCS = f'{FUNC}s'

# %% ../nbs/02_args.ipynb 15
HUSH = 'hush'
SELF = 'self'

QUIET = 'quiet'
RAISE = 'raise'
FAILQ = 'failq'

# %% ../nbs/02_args.ipynb 16
SPEC = 'spec'
SPECS = f'{SPEC}s'

# %% ../nbs/02_args.ipynb 17
ANTI = 'anti'
PTTN = 'pttn'
PATTERN = 'pattern'

ANTI_PTTN = f'{ANTI}_{PTTN}'

# %% ../nbs/02_args.ipynb 18
DEBUG = 'debug'
PRINT = 'print'
VALUE = 'value'
GUARD = 'guard'
ERROR = 'error'

COLOR = 'color'
LABEL = 'label'
TITLE = 'title'

NBINS = 'nbins'

# %% ../nbs/02_args.ipynb 19
CUTOFF = 'cutoff'
MIXINS = 'mixins'
UNIQUE = 'unique'

# %% ../nbs/02_args.ipynb 20
HIDDEN = 'hidden'
IGNORE = 'ignore'
ORIGIN = 'origin'

# %% ../nbs/02_args.ipynb 21
DEFAULT = 'default'
INPLACE = 'inplace'
VERBOSE = 'verbose'
REVERSE = 'reverse'
EXCLUDE = 'exclude'
SPECIAL = 'special'

# %% ../nbs/02_args.ipynb 22
OPTIONAL = 'optional'
REQUIRED = 'required'

# %% ../nbs/02_args.ipynb 24
ASMEMBER = 'asmember'

# %% ../nbs/02_args.ipynb 26
ABRV = 'abrv'
SYMB = 'symb'

CONS = 'cons'

# %% ../nbs/02_args.ipynb 27
FMTFUNC = f'{FMT}{FUNC}'

# %% ../nbs/02_args.ipynb 30
MOD = 'mod'
PKG = 'pkg'

# %% ../nbs/02_args.ipynb 32
ARG = 'arg'
KWS = 'kws'
VAR = 'var'
KWDS = 'kwds'
ARGS = f'{ARG}s'
KWARGS = f'kw{ARGS}'
VARS = f'{VAR}s'
VARG = f'v{ARG}'
VKWS = f'v{KWS}'
VARGS = f'v{ARGS}'
VKWDS = f'v{KWDS}'
VKWARGS = f'v{KWARGS}'
SELF = 'self'

# %% ../nbs/02_args.ipynb 33
DROP = 'drop'
DROPNONE = f'{DROP}none'


# %% ../nbs/02_args.ipynb 35
BEG = 'beg' # beginning
END = 'end' # end / ending

POS = 'pos' # positive
NEG = 'neg' # nevative

LEN = 'len' # length
DIG = 'dig' # digits

BRV = 'brv' # brv / abbreviation
FIX = 'fix' # prefix / suffix

PREFIX = f'pre{FIX}'
SUFFIX = f'suf{FIX}'

STRS = 'strs'

# %% ../nbs/02_args.ipynb 36
SUNDER = 'sunder'
DUNDER = 'dunder'
MANGLED = 'mangled'
PRIVATE = 'private'

# %% ../nbs/02_args.ipynb 37
CHAR = 'char'


# %% ../nbs/02_args.ipynb 39
PROP = 'prop'
PROPS = f'{PROP}s'
PROPERTY = f'{PROP}erty'

# %% ../nbs/02_args.ipynb 41
OVERWRITE = 'overwrite'
OVERWRITABLE = 'overwritable'

# %% ../nbs/02_args.ipynb 42
ALT = 'alt'
ALTS = f'{ALT}s'
ALTER = 'alter'
ALTERNATES = f'{ALTER}nates'
