# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/42_fmtx.ipynb.

# %% auto 0
__all__ = ['MATRIX', 'BARCODES', 'FEATURES', 'SENSITIVITY', 'FILTERED_MATRIX', 'FilteredMatrixFile']

# %% ../nbs/42_fmtx.ipynb 4
from enum import StrEnum

# %% ../nbs/42_fmtx.ipynb 5
from .biol import MATRIX, BARCODES, FEATURES, ADATA
from .exts import EXT_MTX, EXT_TSV, EXT_H5

# %% ../nbs/42_fmtx.ipynb 7
MATRIX = 'matrix'
BARCODES = 'barcodes'
FEATURES = 'features'
SENSITIVITY = 'sensitivity'
FILTERED_MATRIX = f'filtered_{MATRIX}'

# %% ../nbs/42_fmtx.ipynb 8
class FilteredMatrixFile(StrEnum):
    MATRIX = f'{MATRIX}{EXT_MTX}'
    BARCODES = f'{BARCODES}{EXT_TSV}'
    FEATURES = f'{FEATURES}{EXT_TSV}'
    ADATA = f'{ADATA}{EXT_H5}'
