# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/21_clrs.ipynb.

# %% auto 0
__all__ = ['ALICEBLUE', 'ANTIQUEWHITE', 'AQUA', 'AQUAMARINE', 'AZURE', 'B', 'BEIGE', 'BISQUE', 'BLACK', 'BLANCHEDALMOND', 'BLUE',
           'BLUEVIOLET', 'BROWN', 'BURLYWOOD', 'C', 'CADETBLUE', 'CHARTREUSE', 'CHOCOLATE', 'CORAL', 'CORNFLOWERBLUE',
           'CORNSILK', 'CRIMSON', 'CYAN', 'DARKBLUE', 'DARKCYAN', 'DARKGOLDENROD', 'DARKGRAY', 'DARKGREEN', 'DARKGREY',
           'DARKKHAKI', 'DARKMAGENTA', 'DARKOLIVEGREEN', 'DARKORANGE', 'DARKORCHID', 'DARKRED', 'DARKSALMON',
           'DARKSEAGREEN', 'DARKSLATEBLUE', 'DARKSLATEGRAY', 'DARKSLATEGREY', 'DARKTURQUOISE', 'DARKVIOLET', 'DEEPPINK',
           'DEEPSKYBLUE', 'DIMGRAY', 'DIMGREY', 'DODGERBLUE', 'FIREBRICK', 'FLORALWHITE', 'FORESTGREEN', 'FUCHSIA', 'G',
           'GAINSBORO', 'GHOSTWHITE', 'GOLD', 'GOLDENROD', 'GRAY', 'GREEN', 'GREENYELLOW', 'GREY', 'HONEYDEW',
           'HOTPINK', 'INDIANRED', 'INDIGO', 'IVORY', 'K', 'KHAKI', 'LAVENDER', 'LAVENDERBLUSH', 'LAWNGREEN',
           'LEMONCHIFFON', 'LIGHTBLUE', 'LIGHTCORAL', 'LIGHTCYAN', 'LIGHTGOLDENRODYELLOW', 'LIGHTGRAY', 'LIGHTGREEN',
           'LIGHTGREY', 'LIGHTPINK', 'LIGHTSALMON', 'LIGHTSEAGREEN', 'LIGHTSKYBLUE', 'LIGHTSLATEGRAY', 'LIGHTSLATEGREY',
           'LIGHTSTEELBLUE', 'LIGHTYELLOW', 'LIME', 'LIMEGREEN', 'LINEN', 'M', 'MAGENTA', 'MAROON', 'MEDIUMAQUAMARINE',
           'MEDIUMBLUE', 'MEDIUMORCHID', 'MEDIUMPURPLE', 'MEDIUMSEAGREEN', 'MEDIUMSLATEBLUE', 'MEDIUMSPRINGGREEN',
           'MEDIUMTURQUOISE', 'MEDIUMVIOLETRED', 'MIDNIGHTBLUE', 'MINTCREAM', 'MISTYROSE', 'MOCCASIN', 'NAVAJOWHITE',
           'NAVY', 'OLDLACE', 'OLIVE', 'OLIVEDRAB', 'ORANGE', 'ORANGERED', 'ORCHID', 'PALEGOLDENROD', 'PALEGREEN',
           'PALETURQUOISE', 'PALEVIOLETRED', 'PAPAYAWHIP', 'PEACHPUFF', 'PERU', 'PINK', 'PLUM', 'POWDERBLUE', 'PURPLE',
           'R', 'REBECCAPURPLE', 'RED', 'ROSYBROWN', 'ROYALBLUE', 'SADDLEBROWN', 'SALMON', 'SANDYBROWN', 'SEAGREEN',
           'SEASHELL', 'SIENNA', 'SILVER', 'SKYBLUE', 'SLATEBLUE', 'SLATEGRAY', 'SLATEGREY', 'SNOW', 'SPRINGGREEN',
           'STEELBLUE', 'TAB_BLUE', 'TAB_BROWN', 'TAB_CYAN', 'TAB_GRAY', 'TAB_GREEN', 'TAB_OLIVE', 'TAB_ORANGE',
           'TAB_PINK', 'TAB_PURPLE', 'TAB_RED', 'TAN', 'TEAL', 'THISTLE', 'TOMATO', 'TURQUOISE', 'VIOLET', 'W', 'WHEAT',
           'WHITE', 'WHITESMOKE', 'Y', 'YELLOW', 'YELLOWGREEN']

# %% ../nbs/21_clrs.ipynb 6
ALICEBLUE            = 'aliceblue'
ANTIQUEWHITE         = 'antiquewhite'
AQUA                 = 'aqua'
AQUAMARINE           = 'aquamarine'
AZURE                = 'azure'
B                    = 'b'
BEIGE                = 'beige'
BISQUE               = 'bisque'
BLACK                = 'black'
BLANCHEDALMOND       = 'blanchedalmond'
BLUE                 = 'blue'
BLUEVIOLET           = 'blueviolet'
BROWN                = 'brown'
BURLYWOOD            = 'burlywood'
C                    = 'c'
CADETBLUE            = 'cadetblue'
CHARTREUSE           = 'chartreuse'
CHOCOLATE            = 'chocolate'
CORAL                = 'coral'
CORNFLOWERBLUE       = 'cornflowerblue'
CORNSILK             = 'cornsilk'
CRIMSON              = 'crimson'
CYAN                 = 'cyan'
DARKBLUE             = 'darkblue'
DARKCYAN             = 'darkcyan'
DARKGOLDENROD        = 'darkgoldenrod'
DARKGRAY             = 'darkgray'
DARKGREEN            = 'darkgreen'
DARKGREY             = 'darkgrey'
DARKKHAKI            = 'darkkhaki'
DARKMAGENTA          = 'darkmagenta'
DARKOLIVEGREEN       = 'darkolivegreen'
DARKORANGE           = 'darkorange'
DARKORCHID           = 'darkorchid'
DARKRED              = 'darkred'
DARKSALMON           = 'darksalmon'
DARKSEAGREEN         = 'darkseagreen'
DARKSLATEBLUE        = 'darkslateblue'
DARKSLATEGRAY        = 'darkslategray'
DARKSLATEGREY        = 'darkslategrey'
DARKTURQUOISE        = 'darkturquoise'
DARKVIOLET           = 'darkviolet'
DEEPPINK             = 'deeppink'
DEEPSKYBLUE          = 'deepskyblue'
DIMGRAY              = 'dimgray'
DIMGREY              = 'dimgrey'
DODGERBLUE           = 'dodgerblue'
FIREBRICK            = 'firebrick'
FLORALWHITE          = 'floralwhite'
FORESTGREEN          = 'forestgreen'
FUCHSIA              = 'fuchsia'
G                    = 'g'
GAINSBORO            = 'gainsboro'
GHOSTWHITE           = 'ghostwhite'
GOLD                 = 'gold'
GOLDENROD            = 'goldenrod'
GRAY                 = 'gray'
GREEN                = 'green'
GREENYELLOW          = 'greenyellow'
GREY                 = 'grey'
HONEYDEW             = 'honeydew'
HOTPINK              = 'hotpink'
INDIANRED            = 'indianred'
INDIGO               = 'indigo'
IVORY                = 'ivory'
K                    = 'k'
KHAKI                = 'khaki'
LAVENDER             = 'lavender'
LAVENDERBLUSH        = 'lavenderblush'
LAWNGREEN            = 'lawngreen'
LEMONCHIFFON         = 'lemonchiffon'
LIGHTBLUE            = 'lightblue'
LIGHTCORAL           = 'lightcoral'
LIGHTCYAN            = 'lightcyan'
LIGHTGOLDENRODYELLOW = 'lightgoldenrodyellow'
LIGHTGRAY            = 'lightgray'
LIGHTGREEN           = 'lightgreen'
LIGHTGREY            = 'lightgrey'
LIGHTPINK            = 'lightpink'
LIGHTSALMON          = 'lightsalmon'
LIGHTSEAGREEN        = 'lightseagreen'
LIGHTSKYBLUE         = 'lightskyblue'
LIGHTSLATEGRAY       = 'lightslategray'
LIGHTSLATEGREY       = 'lightslategrey'
LIGHTSTEELBLUE       = 'lightsteelblue'
LIGHTYELLOW          = 'lightyellow'
LIME                 = 'lime'
LIMEGREEN            = 'limegreen'
LINEN                = 'linen'
M                    = 'm'
MAGENTA              = 'magenta'
MAROON               = 'maroon'
MEDIUMAQUAMARINE     = 'mediumaquamarine'
MEDIUMBLUE           = 'mediumblue'
MEDIUMORCHID         = 'mediumorchid'
MEDIUMPURPLE         = 'mediumpurple'
MEDIUMSEAGREEN       = 'mediumseagreen'
MEDIUMSLATEBLUE      = 'mediumslateblue'
MEDIUMSPRINGGREEN    = 'mediumspringgreen'
MEDIUMTURQUOISE      = 'mediumturquoise'
MEDIUMVIOLETRED      = 'mediumvioletred'
MIDNIGHTBLUE         = 'midnightblue'
MINTCREAM            = 'mintcream'
MISTYROSE            = 'mistyrose'
MOCCASIN             = 'moccasin'
NAVAJOWHITE          = 'navajowhite'
NAVY                 = 'navy'
OLDLACE              = 'oldlace'
OLIVE                = 'olive'
OLIVEDRAB            = 'olivedrab'
ORANGE               = 'orange'
ORANGERED            = 'orangered'
ORCHID               = 'orchid'
PALEGOLDENROD        = 'palegoldenrod'
PALEGREEN            = 'palegreen'
PALETURQUOISE        = 'paleturquoise'
PALEVIOLETRED        = 'palevioletred'
PAPAYAWHIP           = 'papayawhip'
PEACHPUFF            = 'peachpuff'
PERU                 = 'peru'
PINK                 = 'pink'
PLUM                 = 'plum'
POWDERBLUE           = 'powderblue'
PURPLE               = 'purple'
R                    = 'r'
REBECCAPURPLE        = 'rebeccapurple'
RED                  = 'red'
ROSYBROWN            = 'rosybrown'
ROYALBLUE            = 'royalblue'
SADDLEBROWN          = 'saddlebrown'
SALMON               = 'salmon'
SANDYBROWN           = 'sandybrown'
SEAGREEN             = 'seagreen'
SEASHELL             = 'seashell'
SIENNA               = 'sienna'
SILVER               = 'silver'
SKYBLUE              = 'skyblue'
SLATEBLUE            = 'slateblue'
SLATEGRAY            = 'slategray'
SLATEGREY            = 'slategrey'
SNOW                 = 'snow'
SPRINGGREEN          = 'springgreen'
STEELBLUE            = 'steelblue'
TAB_BLUE             = 'tab:blue'
TAB_BROWN            = 'tab:brown'
TAB_CYAN             = 'tab:cyan'
TAB_GRAY             = 'tab:gray'
TAB_GREEN            = 'tab:green'
TAB_OLIVE            = 'tab:olive'
TAB_ORANGE           = 'tab:orange'
TAB_PINK             = 'tab:pink'
TAB_PURPLE           = 'tab:purple'
TAB_RED              = 'tab:red'
TAN                  = 'tan'
TEAL                 = 'teal'
THISTLE              = 'thistle'
TOMATO               = 'tomato'
TURQUOISE            = 'turquoise'
VIOLET               = 'violet'
W                    = 'w'
WHEAT                = 'wheat'
WHITE                = 'white'
WHITESMOKE           = 'whitesmoke'
Y                    = 'y'
YELLOW               = 'yellow'
YELLOWGREEN          = 'yellowgreen'
