# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/10_ncls.ipynb.

# %% auto 0
__all__ = ['CLS', 'KLS', 'SUB', 'CLASS', 'KLASS', 'SUBCLASS', 'CLSVARS', 'CLSNAME', 'KLSVARS', 'KLSNAME', 'SUBVARS', 'SUBNAME',
           'GEN', 'CON', 'DEC', 'RAW', 'DUCK', 'META', 'GUARD', 'TYPEGUARD', 'NAMESPACE', 'GENERATOR', 'CONSTRUCT',
           'DECORATOR', 'BASE', 'BASES', 'RETURN', 'ASSET', 'AREPR', 'DEFAULT', 'IMPORTED', 'SYSTEM', 'SYSTEMS', 'DCT',
           'NON', 'SIG']

# %% ../nbs/10_ncls.ipynb 5
CLS = 'cls'
KLS = 'kls'
SUB = 'sub'

CLASS = 'class'
KLASS = 'klass'
SUBCLASS = f'{SUB}class'

CLSVARS = f'{CLS}vars'
CLSNAME = f'{CLS}name'

KLSVARS = f'{KLS}vars'
KLSNAME = f'{KLS}name'

SUBVARS = f'{SUB}vars'
SUBNAME = f'{SUB}name'

# %% ../nbs/10_ncls.ipynb 6
GEN = 'gen'
CON = 'con'
DEC = 'dec'
RAW = 'raw'

DUCK = 'duck'
META = 'meta'

GUARD = 'guard'
TYPEGUARD = f'type{GUARD}'


NAMESPACE = 'namespace'
GENERATOR = 'generator'
CONSTRUCT = 'construct'
DECORATOR = 'decorator'

BASE = 'base'
BASES = f'{BASE}s'

RETURN = 'return'

ASSET = 'asset'
AREPR = 'arepr'
DEFAULT = 'default'
IMPORTED = 'imported'

# %% ../nbs/10_ncls.ipynb 7
SYSTEM = 'system'
SYSTEMS = f'{SYSTEM}s'

# %% ../nbs/10_ncls.ipynb 8
DCT = 'dct'
NON = 'non'
SIG = 'sig'
